@@ -1,6 +1,7 @@
 import psycopg2
 from psycopg2.extensions import ISOLATION_LEVEL_AUTOCOMMIT, ISOLATION_LEVEL_DEFAULT
-from utilities import config_create, config
+import json
+from configparser import ConfigParser
 import json
 try:
     import importlib.resources as pkg_resources
@@ -11,6 +12,25 @@ except:
 
 HOST = "localhost"
 
+def config(file_name="database.ini", section="postgresql"):
+    parser = ConfigParser()
+    parser.read(file_name)
+    db = {}
+    if parser.has_section(section):
+        params = parser.items(section)
+        for i in params:
+            db[i[0]] = i[1]
+    return db
+
+def config_create(file_name="database.ini", section="postgresql", host="localhost", database="geotag"):
+    parser = ConfigParser()
+    parser.read(file_name)
+    parser.add_section(section)
+    parser.set(section, "host", host)
+    parser.set(section, "database", database)
+    with open(file_name, "a") as inifile:
+        parser.write(inifile)
+
 def create_db(username="postgress", password=""):
     print("This script creates a database named geotag, It can not be used to update said database continue?:")
     x = input("y/n")
